@@ -1,6 +1,6 @@
 package Enbld::Command::Rehash;
 
-use 5.012;
+use strict;
 use warnings;
 
 use parent qw/Enbld::Command/;
@@ -33,4 +33,4 @@ sub do {
     return $target_name;
 }
 
-1;
+1;
\ No newline at end of file
